# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ResumeResponseDataResumedataPersonname(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fullname': 'str',
        'firstname': 'str',
        'middlename': 'str',
        'lastname': 'str'
    }

    attribute_map = {
        'fullname': 'fullname',
        'firstname': 'firstname',
        'middlename': 'middlename',
        'lastname': 'lastname'
    }

    def __init__(self, fullname=None, firstname=None, middlename=None, lastname=None):  # noqa: E501
        """ResumeResponseDataResumedataPersonname - a model defined in Swagger"""  # noqa: E501
        self._fullname = None
        self._firstname = None
        self._middlename = None
        self._lastname = None
        self.discriminator = None
        if fullname is not None:
            self.fullname = fullname
        if firstname is not None:
            self.firstname = firstname
        if middlename is not None:
            self.middlename = middlename
        if lastname is not None:
            self.lastname = lastname

    @property
    def fullname(self):
        """Gets the fullname of this ResumeResponseDataResumedataPersonname.  # noqa: E501

        Full name of Candidate.  # noqa: E501

        :return: The fullname of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :rtype: str
        """
        return self._fullname

    @fullname.setter
    def fullname(self, fullname):
        """Sets the fullname of this ResumeResponseDataResumedataPersonname.

        Full name of Candidate.  # noqa: E501

        :param fullname: The fullname of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :type: str
        """

        self._fullname = fullname

    @property
    def firstname(self):
        """Gets the firstname of this ResumeResponseDataResumedataPersonname.  # noqa: E501

        First name of Candidate.  # noqa: E501

        :return: The firstname of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this ResumeResponseDataResumedataPersonname.

        First name of Candidate.  # noqa: E501

        :param firstname: The firstname of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def middlename(self):
        """Gets the middlename of this ResumeResponseDataResumedataPersonname.  # noqa: E501

        Middle name of Candidate.  # noqa: E501

        :return: The middlename of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :rtype: str
        """
        return self._middlename

    @middlename.setter
    def middlename(self, middlename):
        """Sets the middlename of this ResumeResponseDataResumedataPersonname.

        Middle name of Candidate.  # noqa: E501

        :param middlename: The middlename of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :type: str
        """

        self._middlename = middlename

    @property
    def lastname(self):
        """Gets the lastname of this ResumeResponseDataResumedataPersonname.  # noqa: E501

        Last name of Candidate.  # noqa: E501

        :return: The lastname of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this ResumeResponseDataResumedataPersonname.

        Last name of Candidate.  # noqa: E501

        :param lastname: The lastname of this ResumeResponseDataResumedataPersonname.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResumeResponseDataResumedataPersonname, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResumeResponseDataResumedataPersonname):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    employees-api-courses

    The Employee course APIs are related to the courses that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.employeescourses.models.bad_request import BadRequest
from phenom.api.employeescourses.models.course import Course
from phenom.api.employeescourses.models.courses_success_response import CoursesSuccessResponse
from phenom.api.employeescourses.models.courses_success_response_with_data import CoursesSuccessResponseWithData
from phenom.api.employeescourses.models.create_course import CreateCourse
from phenom.api.employeescourses.models.error_response import ErrorResponse
from phenom.api.employeescourses.models.get_all_saved_courses import GetAllSavedCourses
from phenom.api.employeescourses.models.get_all_saved_courses_data import GetAllSavedCoursesData
from phenom.api.employeescourses.models.get_all_saved_courses_data_default import GetAllSavedCoursesDataDefault
from phenom.api.employeescourses.models.get_completed_courses_data import GetCompletedCoursesData
from phenom.api.employeescourses.models.save_course import SaveCourse
from phenom.api.employeescourses.models.un_save_course import UnSaveCourse
from phenom.api.employeescourses.models.update_course import UpdateCourse
from phenom.api.employeescourses.models.update_course_status import UpdateCourseStatus



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateProjectRequestHiringTeamList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'email_id': 'str',
        'type': 'str',
        'role': 'str',
        'id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'email_id': 'emailId',
        'type': 'type',
        'role': 'role',
        'id': 'id'
    }

    def __init__(self, name=None, email_id=None, type=None, role=None, id=None):  # noqa: E501
        """CreateProjectRequestHiringTeamList - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._email_id = None
        self._type = None
        self._role = None
        self._id = None
        self.discriminator = None
        self.name = name
        self.email_id = email_id
        self.type = type
        self.role = role
        self.id = id

    @property
    def name(self):
        """Gets the name of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Name of the team member.  # noqa: E501

        :return: The name of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateProjectRequestHiringTeamList.

        Name of the team member.  # noqa: E501

        :param name: The name of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def email_id(self):
        """Gets the email_id of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Email ID of the team member.  # noqa: E501

        :return: The email_id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this CreateProjectRequestHiringTeamList.

        Email ID of the team member.  # noqa: E501

        :param email_id: The email_id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if email_id is None:
            raise ValueError("Invalid value for `email_id`, must not be `None`")  # noqa: E501

        self._email_id = email_id

    @property
    def type(self):
        """Gets the type of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Type of the team member.  # noqa: E501

        :return: The type of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateProjectRequestHiringTeamList.

        Type of the team member.  # noqa: E501

        :param type: The type of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def role(self):
        """Gets the role of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Role of the team member.  # noqa: E501

        :return: The role of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this CreateProjectRequestHiringTeamList.

        Role of the team member.  # noqa: E501

        :param role: The role of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501

        self._role = role

    @property
    def id(self):
        """Gets the id of this CreateProjectRequestHiringTeamList.  # noqa: E501

        ID of the team member.  # noqa: E501

        :return: The id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateProjectRequestHiringTeamList.

        ID of the team member.  # noqa: E501

        :param id: The id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateProjectRequestHiringTeamList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateProjectRequestHiringTeamList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    employees-api-referral

    The employee referral APIs are used to refer, track and recommend jobs to external candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ReferralData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'category': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'phone': 'str',
        'message': 'str',
        'questionnaire': 'ReferralDataQuestionnaire'
    }

    attribute_map = {
        'job_id': 'jobId',
        'category': 'category',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'phone': 'phone',
        'message': 'message',
        'questionnaire': 'questionnaire'
    }

    def __init__(self, job_id='12121', category='Engineering', first_name='John', last_name='Deal', phone='919181912122', message='APPLY NOW', questionnaire=None):  # noqa: E501
        """ReferralData - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._category = None
        self._first_name = None
        self._last_name = None
        self._phone = None
        self._message = None
        self._questionnaire = None
        self.discriminator = None
        if job_id is not None:
            self.job_id = job_id
        if category is not None:
            self.category = category
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if phone is not None:
            self.phone = phone
        if message is not None:
            self.message = message
        if questionnaire is not None:
            self.questionnaire = questionnaire

    @property
    def job_id(self):
        """Gets the job_id of this ReferralData.  # noqa: E501

        Job Id - unique field to identify the job.  # noqa: E501

        :return: The job_id of this ReferralData.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ReferralData.

        Job Id - unique field to identify the job.  # noqa: E501

        :param job_id: The job_id of this ReferralData.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def category(self):
        """Gets the category of this ReferralData.  # noqa: E501

        Category of the job that employee is making a referral.  # noqa: E501

        :return: The category of this ReferralData.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ReferralData.

        Category of the job that employee is making a referral.  # noqa: E501

        :param category: The category of this ReferralData.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def first_name(self):
        """Gets the first_name of this ReferralData.  # noqa: E501

        FirstName of the candidate which employee is referring.  # noqa: E501

        :return: The first_name of this ReferralData.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ReferralData.

        FirstName of the candidate which employee is referring.  # noqa: E501

        :param first_name: The first_name of this ReferralData.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ReferralData.  # noqa: E501

        LastName of the candidate which employee is referring.  # noqa: E501

        :return: The last_name of this ReferralData.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ReferralData.

        LastName of the candidate which employee is referring.  # noqa: E501

        :param last_name: The last_name of this ReferralData.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def phone(self):
        """Gets the phone of this ReferralData.  # noqa: E501

        Phone Number of the candidate which employee is referring.  # noqa: E501

        :return: The phone of this ReferralData.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this ReferralData.

        Phone Number of the candidate which employee is referring.  # noqa: E501

        :param phone: The phone of this ReferralData.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def message(self):
        """Gets the message of this ReferralData.  # noqa: E501

        Personal Message to the candidate which employee is referring.  # noqa: E501

        :return: The message of this ReferralData.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ReferralData.

        Personal Message to the candidate which employee is referring.  # noqa: E501

        :param message: The message of this ReferralData.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def questionnaire(self):
        """Gets the questionnaire of this ReferralData.  # noqa: E501


        :return: The questionnaire of this ReferralData.  # noqa: E501
        :rtype: ReferralDataQuestionnaire
        """
        return self._questionnaire

    @questionnaire.setter
    def questionnaire(self, questionnaire):
        """Sets the questionnaire of this ReferralData.


        :param questionnaire: The questionnaire of this ReferralData.  # noqa: E501
        :type: ReferralDataQuestionnaire
        """

        self._questionnaire = questionnaire

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReferralData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReferralData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    search-api

    These APIs helps to search and suggest based on keyword among available jobs.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobSearchRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'keywords': 'str',
        '_from': 'int',
        'size': 'int',
        'boolean_operator': 'str',
        'locale': 'str',
        'site_type': 'str',
        'user_type': 'str',
        'order_by': 'str',
        'facets': 'JobSearchRequestFacets',
        'ip': 'str',
        'location_data': 'LocationData'
    }

    attribute_map = {
        'keywords': 'keywords',
        '_from': 'from',
        'size': 'size',
        'boolean_operator': 'booleanOperator',
        'locale': 'locale',
        'site_type': 'siteType',
        'user_type': 'userType',
        'order_by': 'orderBy',
        'facets': 'facets',
        'ip': 'ip',
        'location_data': 'locationData'
    }

    def __init__(self, keywords=None, _from=None, size=None, boolean_operator=None, locale=None, site_type=None, user_type=None, order_by=None, facets=None, ip=None, location_data=None):  # noqa: E501
        """JobSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._keywords = None
        self.__from = None
        self._size = None
        self._boolean_operator = None
        self._locale = None
        self._site_type = None
        self._user_type = None
        self._order_by = None
        self._facets = None
        self._ip = None
        self._location_data = None
        self.discriminator = None
        if keywords is not None:
            self.keywords = keywords
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size
        if boolean_operator is not None:
            self.boolean_operator = boolean_operator
        if locale is not None:
            self.locale = locale
        if site_type is not None:
            self.site_type = site_type
        if user_type is not None:
            self.user_type = user_type
        if order_by is not None:
            self.order_by = order_by
        if facets is not None:
            self.facets = facets
        if ip is not None:
            self.ip = ip
        if location_data is not None:
            self.location_data = location_data

    @property
    def keywords(self):
        """Gets the keywords of this JobSearchRequest.  # noqa: E501

        Keyword to search.  # noqa: E501

        :return: The keywords of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this JobSearchRequest.

        Keyword to search.  # noqa: E501

        :param keywords: The keywords of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._keywords = keywords

    @property
    def _from(self):
        """Gets the _from of this JobSearchRequest.  # noqa: E501

        Starting point from which the data should be retrieved.  # noqa: E501

        :return: The _from of this JobSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this JobSearchRequest.

        Starting point from which the data should be retrieved.  # noqa: E501

        :param _from: The _from of this JobSearchRequest.  # noqa: E501
        :type: int
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this JobSearchRequest.  # noqa: E501

        Size of the response.  # noqa: E501

        :return: The size of this JobSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this JobSearchRequest.

        Size of the response.  # noqa: E501

        :param size: The size of this JobSearchRequest.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def boolean_operator(self):
        """Gets the boolean_operator of this JobSearchRequest.  # noqa: E501

        Search operator accepts \"and\" / \"or\".  # noqa: E501

        :return: The boolean_operator of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._boolean_operator

    @boolean_operator.setter
    def boolean_operator(self, boolean_operator):
        """Sets the boolean_operator of this JobSearchRequest.

        Search operator accepts \"and\" / \"or\".  # noqa: E501

        :param boolean_operator: The boolean_operator of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._boolean_operator = boolean_operator

    @property
    def locale(self):
        """Gets the locale of this JobSearchRequest.  # noqa: E501

        Locale of the site (Language_Country) - Example: en_US.  # noqa: E501

        :return: The locale of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobSearchRequest.

        Locale of the site (Language_Country) - Example: en_US.  # noqa: E501

        :param locale: The locale of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def site_type(self):
        """Gets the site_type of this JobSearchRequest.  # noqa: E501

        Persona Value - Example: Internal, External.  # noqa: E501

        :return: The site_type of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobSearchRequest.

        Persona Value - Example: Internal, External.  # noqa: E501

        :param site_type: The site_type of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._site_type = site_type

    @property
    def user_type(self):
        """Gets the user_type of this JobSearchRequest.  # noqa: E501

        Type of the user - Internal or External User.  # noqa: E501

        :return: The user_type of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this JobSearchRequest.

        Type of the user - Internal or External User.  # noqa: E501

        :param user_type: The user_type of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    @property
    def order_by(self):
        """Gets the order_by of this JobSearchRequest.  # noqa: E501

        Resultant order of jobs.  # noqa: E501

        :return: The order_by of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this JobSearchRequest.

        Resultant order of jobs.  # noqa: E501

        :param order_by: The order_by of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._order_by = order_by

    @property
    def facets(self):
        """Gets the facets of this JobSearchRequest.  # noqa: E501


        :return: The facets of this JobSearchRequest.  # noqa: E501
        :rtype: JobSearchRequestFacets
        """
        return self._facets

    @facets.setter
    def facets(self, facets):
        """Sets the facets of this JobSearchRequest.


        :param facets: The facets of this JobSearchRequest.  # noqa: E501
        :type: JobSearchRequestFacets
        """

        self._facets = facets

    @property
    def ip(self):
        """Gets the ip of this JobSearchRequest.  # noqa: E501

        User IP Address.  # noqa: E501

        :return: The ip of this JobSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this JobSearchRequest.

        User IP Address.  # noqa: E501

        :param ip: The ip of this JobSearchRequest.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def location_data(self):
        """Gets the location_data of this JobSearchRequest.  # noqa: E501


        :return: The location_data of this JobSearchRequest.  # noqa: E501
        :rtype: LocationData
        """
        return self._location_data

    @location_data.setter
    def location_data(self, location_data):
        """Sets the location_data of this JobSearchRequest.


        :param location_data: The location_data of this JobSearchRequest.  # noqa: E501
        :type: LocationData
        """

        self._location_data = location_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Empty(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """Empty - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Empty, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Empty):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateCandidateRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'middle_name': 'str',
        'email_list': 'list[UpdateCandidateRequestEmailList]',
        'contacts': 'list[UpdateCandidateRequestContacts]',
        'linked_in_profile_url': 'str',
        'ats_id': 'str',
        'employee_id': 'str',
        'internal': 'bool',
        'profile_sources': 'list[str]',
        'created_date': 'str',
        'updated_date': 'str',
        'language_preference': 'str',
        'language_known': 'list[str]',
        'gender': 'str',
        'designation': 'str',
        'race': 'str',
        'veteran': 'str',
        'disability': 'str',
        'ethnicity': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'middle_name': 'middleName',
        'email_list': 'emailList',
        'contacts': 'contacts',
        'linked_in_profile_url': 'linkedInProfileURL',
        'ats_id': 'atsId',
        'employee_id': 'employeeId',
        'internal': 'internal',
        'profile_sources': 'profileSources',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate',
        'language_preference': 'languagePreference',
        'language_known': 'languageKnown',
        'gender': 'gender',
        'designation': 'designation',
        'race': 'race',
        'veteran': 'veteran',
        'disability': 'disability',
        'ethnicity': 'ethnicity'
    }

    def __init__(self, first_name=None, last_name=None, middle_name=None, email_list=None, contacts=None, linked_in_profile_url=None, ats_id=None, employee_id=None, internal=None, profile_sources=None, created_date=None, updated_date=None, language_preference=None, language_known=None, gender=None, designation=None, race=None, veteran=None, disability=None, ethnicity=None):  # noqa: E501
        """UpdateCandidateRequest - a model defined in Swagger"""  # noqa: E501
        self._first_name = None
        self._last_name = None
        self._middle_name = None
        self._email_list = None
        self._contacts = None
        self._linked_in_profile_url = None
        self._ats_id = None
        self._employee_id = None
        self._internal = None
        self._profile_sources = None
        self._created_date = None
        self._updated_date = None
        self._language_preference = None
        self._language_known = None
        self._gender = None
        self._designation = None
        self._race = None
        self._veteran = None
        self._disability = None
        self._ethnicity = None
        self.discriminator = None
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if middle_name is not None:
            self.middle_name = middle_name
        if email_list is not None:
            self.email_list = email_list
        if contacts is not None:
            self.contacts = contacts
        if linked_in_profile_url is not None:
            self.linked_in_profile_url = linked_in_profile_url
        if ats_id is not None:
            self.ats_id = ats_id
        if employee_id is not None:
            self.employee_id = employee_id
        if internal is not None:
            self.internal = internal
        if profile_sources is not None:
            self.profile_sources = profile_sources
        if created_date is not None:
            self.created_date = created_date
        if updated_date is not None:
            self.updated_date = updated_date
        if language_preference is not None:
            self.language_preference = language_preference
        if language_known is not None:
            self.language_known = language_known
        if gender is not None:
            self.gender = gender
        if designation is not None:
            self.designation = designation
        if race is not None:
            self.race = race
        if veteran is not None:
            self.veteran = veteran
        if disability is not None:
            self.disability = disability
        if ethnicity is not None:
            self.ethnicity = ethnicity

    @property
    def first_name(self):
        """Gets the first_name of this UpdateCandidateRequest.  # noqa: E501

        The first name of the candidate.  # noqa: E501

        :return: The first_name of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UpdateCandidateRequest.

        The first name of the candidate.  # noqa: E501

        :param first_name: The first_name of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this UpdateCandidateRequest.  # noqa: E501

        The last name of the candidate.  # noqa: E501

        :return: The last_name of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UpdateCandidateRequest.

        The last name of the candidate.  # noqa: E501

        :param last_name: The last_name of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def middle_name(self):
        """Gets the middle_name of this UpdateCandidateRequest.  # noqa: E501

        The middle name of the candidate.  # noqa: E501

        :return: The middle_name of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this UpdateCandidateRequest.

        The middle name of the candidate.  # noqa: E501

        :param middle_name: The middle_name of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def email_list(self):
        """Gets the email_list of this UpdateCandidateRequest.  # noqa: E501

        Array of email addresses associated with the candidate.  # noqa: E501

        :return: The email_list of this UpdateCandidateRequest.  # noqa: E501
        :rtype: list[UpdateCandidateRequestEmailList]
        """
        return self._email_list

    @email_list.setter
    def email_list(self, email_list):
        """Sets the email_list of this UpdateCandidateRequest.

        Array of email addresses associated with the candidate.  # noqa: E501

        :param email_list: The email_list of this UpdateCandidateRequest.  # noqa: E501
        :type: list[UpdateCandidateRequestEmailList]
        """

        self._email_list = email_list

    @property
    def contacts(self):
        """Gets the contacts of this UpdateCandidateRequest.  # noqa: E501

        Array of contact details associated with the candidate.  # noqa: E501

        :return: The contacts of this UpdateCandidateRequest.  # noqa: E501
        :rtype: list[UpdateCandidateRequestContacts]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this UpdateCandidateRequest.

        Array of contact details associated with the candidate.  # noqa: E501

        :param contacts: The contacts of this UpdateCandidateRequest.  # noqa: E501
        :type: list[UpdateCandidateRequestContacts]
        """

        self._contacts = contacts

    @property
    def linked_in_profile_url(self):
        """Gets the linked_in_profile_url of this UpdateCandidateRequest.  # noqa: E501

        The LinkedIn profile URL of the candidate.  # noqa: E501

        :return: The linked_in_profile_url of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._linked_in_profile_url

    @linked_in_profile_url.setter
    def linked_in_profile_url(self, linked_in_profile_url):
        """Sets the linked_in_profile_url of this UpdateCandidateRequest.

        The LinkedIn profile URL of the candidate.  # noqa: E501

        :param linked_in_profile_url: The linked_in_profile_url of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._linked_in_profile_url = linked_in_profile_url

    @property
    def ats_id(self):
        """Gets the ats_id of this UpdateCandidateRequest.  # noqa: E501

        The ATS (Applicant Tracking System) identifier associated with the candidate.  # noqa: E501

        :return: The ats_id of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._ats_id

    @ats_id.setter
    def ats_id(self, ats_id):
        """Sets the ats_id of this UpdateCandidateRequest.

        The ATS (Applicant Tracking System) identifier associated with the candidate.  # noqa: E501

        :param ats_id: The ats_id of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._ats_id = ats_id

    @property
    def employee_id(self):
        """Gets the employee_id of this UpdateCandidateRequest.  # noqa: E501

        The employee identifier associated with the candidate.  # noqa: E501

        :return: The employee_id of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this UpdateCandidateRequest.

        The employee identifier associated with the candidate.  # noqa: E501

        :param employee_id: The employee_id of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def internal(self):
        """Gets the internal of this UpdateCandidateRequest.  # noqa: E501

        Indicates whether the candidate is internal.  # noqa: E501

        :return: The internal of this UpdateCandidateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this UpdateCandidateRequest.

        Indicates whether the candidate is internal.  # noqa: E501

        :param internal: The internal of this UpdateCandidateRequest.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def profile_sources(self):
        """Gets the profile_sources of this UpdateCandidateRequest.  # noqa: E501

        Array of profile sources associated with the candidate.  # noqa: E501

        :return: The profile_sources of this UpdateCandidateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._profile_sources

    @profile_sources.setter
    def profile_sources(self, profile_sources):
        """Sets the profile_sources of this UpdateCandidateRequest.

        Array of profile sources associated with the candidate.  # noqa: E501

        :param profile_sources: The profile_sources of this UpdateCandidateRequest.  # noqa: E501
        :type: list[str]
        """

        self._profile_sources = profile_sources

    @property
    def created_date(self):
        """Gets the created_date of this UpdateCandidateRequest.  # noqa: E501

        The date and time when the candidate was created in the ATS.  # noqa: E501

        :return: The created_date of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this UpdateCandidateRequest.

        The date and time when the candidate was created in the ATS.  # noqa: E501

        :param created_date: The created_date of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this UpdateCandidateRequest.  # noqa: E501

        The date and time when the candidate record was last updated in the ATS.  # noqa: E501

        :return: The updated_date of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this UpdateCandidateRequest.

        The date and time when the candidate record was last updated in the ATS.  # noqa: E501

        :param updated_date: The updated_date of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def language_preference(self):
        """Gets the language_preference of this UpdateCandidateRequest.  # noqa: E501

        The language preference of the candidate.  # noqa: E501

        :return: The language_preference of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._language_preference

    @language_preference.setter
    def language_preference(self, language_preference):
        """Sets the language_preference of this UpdateCandidateRequest.

        The language preference of the candidate.  # noqa: E501

        :param language_preference: The language_preference of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._language_preference = language_preference

    @property
    def language_known(self):
        """Gets the language_known of this UpdateCandidateRequest.  # noqa: E501

        Array of languages known by the candidate.  # noqa: E501

        :return: The language_known of this UpdateCandidateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._language_known

    @language_known.setter
    def language_known(self, language_known):
        """Sets the language_known of this UpdateCandidateRequest.

        Array of languages known by the candidate.  # noqa: E501

        :param language_known: The language_known of this UpdateCandidateRequest.  # noqa: E501
        :type: list[str]
        """

        self._language_known = language_known

    @property
    def gender(self):
        """Gets the gender of this UpdateCandidateRequest.  # noqa: E501

        The gender of the candidate.  # noqa: E501

        :return: The gender of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this UpdateCandidateRequest.

        The gender of the candidate.  # noqa: E501

        :param gender: The gender of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._gender = gender

    @property
    def designation(self):
        """Gets the designation of this UpdateCandidateRequest.  # noqa: E501

        The designation or job title of the candidate.  # noqa: E501

        :return: The designation of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._designation

    @designation.setter
    def designation(self, designation):
        """Sets the designation of this UpdateCandidateRequest.

        The designation or job title of the candidate.  # noqa: E501

        :param designation: The designation of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._designation = designation

    @property
    def race(self):
        """Gets the race of this UpdateCandidateRequest.  # noqa: E501

        The race or ethnicity of the candidate.  # noqa: E501

        :return: The race of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._race

    @race.setter
    def race(self, race):
        """Sets the race of this UpdateCandidateRequest.

        The race or ethnicity of the candidate.  # noqa: E501

        :param race: The race of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._race = race

    @property
    def veteran(self):
        """Gets the veteran of this UpdateCandidateRequest.  # noqa: E501

        Indicates whether the candidate is a veteran.  # noqa: E501

        :return: The veteran of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._veteran

    @veteran.setter
    def veteran(self, veteran):
        """Sets the veteran of this UpdateCandidateRequest.

        Indicates whether the candidate is a veteran.  # noqa: E501

        :param veteran: The veteran of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._veteran = veteran

    @property
    def disability(self):
        """Gets the disability of this UpdateCandidateRequest.  # noqa: E501

        The disability status of the candidate.  # noqa: E501

        :return: The disability of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._disability

    @disability.setter
    def disability(self, disability):
        """Sets the disability of this UpdateCandidateRequest.

        The disability status of the candidate.  # noqa: E501

        :param disability: The disability of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._disability = disability

    @property
    def ethnicity(self):
        """Gets the ethnicity of this UpdateCandidateRequest.  # noqa: E501

        The ethnicity of the candidate.  # noqa: E501

        :return: The ethnicity of this UpdateCandidateRequest.  # noqa: E501
        :rtype: str
        """
        return self._ethnicity

    @ethnicity.setter
    def ethnicity(self, ethnicity):
        """Sets the ethnicity of this UpdateCandidateRequest.

        The ethnicity of the candidate.  # noqa: E501

        :param ethnicity: The ethnicity of this UpdateCandidateRequest.  # noqa: E501
        :type: str
        """

        self._ethnicity = ethnicity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCandidateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCandidateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class HiringStatusDataApplicationsHiringStatus(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'updated_date': 'float',
        'value': 'str',
        'hs_priority': 'float',
        'previous_rejection_reason_id': 'str',
        'rejection_reason_id': 'str',
        'rejection_reason': 'str',
        'previous_rejection_reason': 'str',
        'previous_value': 'str',
        'is_rejected': 'bool',
        'step': 'str',
        'work_flow_step_id': 'str',
        'previous_work_flow_step_id': 'str'
    }

    attribute_map = {
        'updated_date': 'updatedDate',
        'value': 'value',
        'hs_priority': 'hsPriority',
        'previous_rejection_reason_id': 'previousRejectionReasonId',
        'rejection_reason_id': 'rejectionReasonId',
        'rejection_reason': 'rejectionReason',
        'previous_rejection_reason': 'previousRejectionReason',
        'previous_value': 'previousValue',
        'is_rejected': 'isRejected',
        'step': 'step',
        'work_flow_step_id': 'workFlowStepId',
        'previous_work_flow_step_id': 'previousWorkFlowStepId'
    }

    def __init__(self, updated_date=None, value=None, hs_priority=None, previous_rejection_reason_id=None, rejection_reason_id=None, rejection_reason=None, previous_rejection_reason=None, previous_value=None, is_rejected=None, step=None, work_flow_step_id=None, previous_work_flow_step_id=None):  # noqa: E501
        """HiringStatusDataApplicationsHiringStatus - a model defined in Swagger"""  # noqa: E501
        self._updated_date = None
        self._value = None
        self._hs_priority = None
        self._previous_rejection_reason_id = None
        self._rejection_reason_id = None
        self._rejection_reason = None
        self._previous_rejection_reason = None
        self._previous_value = None
        self._is_rejected = None
        self._step = None
        self._work_flow_step_id = None
        self._previous_work_flow_step_id = None
        self.discriminator = None
        if updated_date is not None:
            self.updated_date = updated_date
        if value is not None:
            self.value = value
        if hs_priority is not None:
            self.hs_priority = hs_priority
        if previous_rejection_reason_id is not None:
            self.previous_rejection_reason_id = previous_rejection_reason_id
        if rejection_reason_id is not None:
            self.rejection_reason_id = rejection_reason_id
        if rejection_reason is not None:
            self.rejection_reason = rejection_reason
        if previous_rejection_reason is not None:
            self.previous_rejection_reason = previous_rejection_reason
        if previous_value is not None:
            self.previous_value = previous_value
        if is_rejected is not None:
            self.is_rejected = is_rejected
        if step is not None:
            self.step = step
        if work_flow_step_id is not None:
            self.work_flow_step_id = work_flow_step_id
        if previous_work_flow_step_id is not None:
            self.previous_work_flow_step_id = previous_work_flow_step_id

    @property
    def updated_date(self):
        """Gets the updated_date of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Date when the hiring status was last updated.  # noqa: E501

        :return: The updated_date of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: float
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this HiringStatusDataApplicationsHiringStatus.

        Date when the hiring status was last updated.  # noqa: E501

        :param updated_date: The updated_date of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: float
        """

        self._updated_date = updated_date

    @property
    def value(self):
        """Gets the value of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Current value of the hiring status.  # noqa: E501

        :return: The value of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this HiringStatusDataApplicationsHiringStatus.

        Current value of the hiring status.  # noqa: E501

        :param value: The value of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def hs_priority(self):
        """Gets the hs_priority of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Priority associated with the hiring status.  # noqa: E501

        :return: The hs_priority of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: float
        """
        return self._hs_priority

    @hs_priority.setter
    def hs_priority(self, hs_priority):
        """Sets the hs_priority of this HiringStatusDataApplicationsHiringStatus.

        Priority associated with the hiring status.  # noqa: E501

        :param hs_priority: The hs_priority of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: float
        """

        self._hs_priority = hs_priority

    @property
    def previous_rejection_reason_id(self):
        """Gets the previous_rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        ID of the previous rejection reason.  # noqa: E501

        :return: The previous_rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._previous_rejection_reason_id

    @previous_rejection_reason_id.setter
    def previous_rejection_reason_id(self, previous_rejection_reason_id):
        """Sets the previous_rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.

        ID of the previous rejection reason.  # noqa: E501

        :param previous_rejection_reason_id: The previous_rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._previous_rejection_reason_id = previous_rejection_reason_id

    @property
    def rejection_reason_id(self):
        """Gets the rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        ID of the current rejection reason.  # noqa: E501

        :return: The rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._rejection_reason_id

    @rejection_reason_id.setter
    def rejection_reason_id(self, rejection_reason_id):
        """Sets the rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.

        ID of the current rejection reason.  # noqa: E501

        :param rejection_reason_id: The rejection_reason_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._rejection_reason_id = rejection_reason_id

    @property
    def rejection_reason(self):
        """Gets the rejection_reason of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Current rejection reason.  # noqa: E501

        :return: The rejection_reason of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._rejection_reason

    @rejection_reason.setter
    def rejection_reason(self, rejection_reason):
        """Sets the rejection_reason of this HiringStatusDataApplicationsHiringStatus.

        Current rejection reason.  # noqa: E501

        :param rejection_reason: The rejection_reason of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._rejection_reason = rejection_reason

    @property
    def previous_rejection_reason(self):
        """Gets the previous_rejection_reason of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Previous rejection reason.  # noqa: E501

        :return: The previous_rejection_reason of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._previous_rejection_reason

    @previous_rejection_reason.setter
    def previous_rejection_reason(self, previous_rejection_reason):
        """Sets the previous_rejection_reason of this HiringStatusDataApplicationsHiringStatus.

        Previous rejection reason.  # noqa: E501

        :param previous_rejection_reason: The previous_rejection_reason of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._previous_rejection_reason = previous_rejection_reason

    @property
    def previous_value(self):
        """Gets the previous_value of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Previous value of the hiring status.  # noqa: E501

        :return: The previous_value of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._previous_value

    @previous_value.setter
    def previous_value(self, previous_value):
        """Sets the previous_value of this HiringStatusDataApplicationsHiringStatus.

        Previous value of the hiring status.  # noqa: E501

        :param previous_value: The previous_value of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._previous_value = previous_value

    @property
    def is_rejected(self):
        """Gets the is_rejected of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Indicates whether the application is rejected.  # noqa: E501

        :return: The is_rejected of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejected

    @is_rejected.setter
    def is_rejected(self, is_rejected):
        """Sets the is_rejected of this HiringStatusDataApplicationsHiringStatus.

        Indicates whether the application is rejected.  # noqa: E501

        :param is_rejected: The is_rejected of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: bool
        """

        self._is_rejected = is_rejected

    @property
    def step(self):
        """Gets the step of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        Current step in the workflow.  # noqa: E501

        :return: The step of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this HiringStatusDataApplicationsHiringStatus.

        Current step in the workflow.  # noqa: E501

        :param step: The step of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._step = step

    @property
    def work_flow_step_id(self):
        """Gets the work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        ID of the current workflow step.  # noqa: E501

        :return: The work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._work_flow_step_id

    @work_flow_step_id.setter
    def work_flow_step_id(self, work_flow_step_id):
        """Sets the work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.

        ID of the current workflow step.  # noqa: E501

        :param work_flow_step_id: The work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._work_flow_step_id = work_flow_step_id

    @property
    def previous_work_flow_step_id(self):
        """Gets the previous_work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501

        ID of the previous workflow step.  # noqa: E501

        :return: The previous_work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :rtype: str
        """
        return self._previous_work_flow_step_id

    @previous_work_flow_step_id.setter
    def previous_work_flow_step_id(self, previous_work_flow_step_id):
        """Sets the previous_work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.

        ID of the previous workflow step.  # noqa: E501

        :param previous_work_flow_step_id: The previous_work_flow_step_id of this HiringStatusDataApplicationsHiringStatus.  # noqa: E501
        :type: str
        """

        self._previous_work_flow_step_id = previous_work_flow_step_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HiringStatusDataApplicationsHiringStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HiringStatusDataApplicationsHiringStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class InviteCandidateResponseDataInvites(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'video_screen_id': 'str',
        'candidate_id': 'str',
        'invitation_code': 'str',
        'expiry_in_days': 'float',
        'date_created': 'int',
        'interview_link': 'str',
        'interview_end_time': 'float',
        'auto_reminder_trigger_time': 'float',
        'auto_reminder_info': 'InviteCandidateResponseDataAutoReminderInfo',
        'status_code': 'float',
        'assessment_status': 'str',
        'status': 'str'
    }

    attribute_map = {
        'video_screen_id': 'videoScreenId',
        'candidate_id': 'candidateId',
        'invitation_code': 'invitationCode',
        'expiry_in_days': 'expiryInDays',
        'date_created': 'dateCreated',
        'interview_link': 'interviewLink',
        'interview_end_time': 'interviewEndTime',
        'auto_reminder_trigger_time': 'autoReminderTriggerTime',
        'auto_reminder_info': 'autoReminderInfo',
        'status_code': 'statusCode',
        'assessment_status': 'assessmentStatus',
        'status': 'status'
    }

    def __init__(self, video_screen_id=None, candidate_id=None, invitation_code=None, expiry_in_days=None, date_created=None, interview_link=None, interview_end_time=None, auto_reminder_trigger_time=None, auto_reminder_info=None, status_code=None, assessment_status=None, status=None):  # noqa: E501
        """InviteCandidateResponseDataInvites - a model defined in Swagger"""  # noqa: E501
        self._video_screen_id = None
        self._candidate_id = None
        self._invitation_code = None
        self._expiry_in_days = None
        self._date_created = None
        self._interview_link = None
        self._interview_end_time = None
        self._auto_reminder_trigger_time = None
        self._auto_reminder_info = None
        self._status_code = None
        self._assessment_status = None
        self._status = None
        self.discriminator = None
        self.video_screen_id = video_screen_id
        self.candidate_id = candidate_id
        self.invitation_code = invitation_code
        self.expiry_in_days = expiry_in_days
        self.date_created = date_created
        self.interview_link = interview_link
        self.interview_end_time = interview_end_time
        self.auto_reminder_trigger_time = auto_reminder_trigger_time
        self.auto_reminder_info = auto_reminder_info
        self.status_code = status_code
        self.assessment_status = assessment_status
        self.status = status

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this InviteCandidateResponseDataInvites.  # noqa: E501

        This is the interview id.  # noqa: E501

        :return: The video_screen_id of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this InviteCandidateResponseDataInvites.

        This is the interview id.  # noqa: E501

        :param video_screen_id: The video_screen_id of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: str
        """
        if video_screen_id is None:
            raise ValueError("Invalid value for `video_screen_id`, must not be `None`")  # noqa: E501

        self._video_screen_id = video_screen_id

    @property
    def candidate_id(self):
        """Gets the candidate_id of this InviteCandidateResponseDataInvites.  # noqa: E501

        Candidate id.  # noqa: E501

        :return: The candidate_id of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this InviteCandidateResponseDataInvites.

        Candidate id.  # noqa: E501

        :param candidate_id: The candidate_id of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: str
        """
        if candidate_id is None:
            raise ValueError("Invalid value for `candidate_id`, must not be `None`")  # noqa: E501

        self._candidate_id = candidate_id

    @property
    def invitation_code(self):
        """Gets the invitation_code of this InviteCandidateResponseDataInvites.  # noqa: E501

        Invitation code for the invite sent.  # noqa: E501

        :return: The invitation_code of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: str
        """
        return self._invitation_code

    @invitation_code.setter
    def invitation_code(self, invitation_code):
        """Sets the invitation_code of this InviteCandidateResponseDataInvites.

        Invitation code for the invite sent.  # noqa: E501

        :param invitation_code: The invitation_code of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: str
        """
        if invitation_code is None:
            raise ValueError("Invalid value for `invitation_code`, must not be `None`")  # noqa: E501

        self._invitation_code = invitation_code

    @property
    def expiry_in_days(self):
        """Gets the expiry_in_days of this InviteCandidateResponseDataInvites.  # noqa: E501

        Interview expiry days. Counts from the invited date.  # noqa: E501

        :return: The expiry_in_days of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: float
        """
        return self._expiry_in_days

    @expiry_in_days.setter
    def expiry_in_days(self, expiry_in_days):
        """Sets the expiry_in_days of this InviteCandidateResponseDataInvites.

        Interview expiry days. Counts from the invited date.  # noqa: E501

        :param expiry_in_days: The expiry_in_days of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: float
        """
        if expiry_in_days is None:
            raise ValueError("Invalid value for `expiry_in_days`, must not be `None`")  # noqa: E501

        self._expiry_in_days = expiry_in_days

    @property
    def date_created(self):
        """Gets the date_created of this InviteCandidateResponseDataInvites.  # noqa: E501

        Date when invite sent.  # noqa: E501

        :return: The date_created of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this InviteCandidateResponseDataInvites.

        Date when invite sent.  # noqa: E501

        :param date_created: The date_created of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def interview_link(self):
        """Gets the interview_link of this InviteCandidateResponseDataInvites.  # noqa: E501

        Interview link.  # noqa: E501

        :return: The interview_link of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: str
        """
        return self._interview_link

    @interview_link.setter
    def interview_link(self, interview_link):
        """Sets the interview_link of this InviteCandidateResponseDataInvites.

        Interview link.  # noqa: E501

        :param interview_link: The interview_link of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: str
        """
        if interview_link is None:
            raise ValueError("Invalid value for `interview_link`, must not be `None`")  # noqa: E501

        self._interview_link = interview_link

    @property
    def interview_end_time(self):
        """Gets the interview_end_time of this InviteCandidateResponseDataInvites.  # noqa: E501

        Expiry Timestamp  # noqa: E501

        :return: The interview_end_time of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: float
        """
        return self._interview_end_time

    @interview_end_time.setter
    def interview_end_time(self, interview_end_time):
        """Sets the interview_end_time of this InviteCandidateResponseDataInvites.

        Expiry Timestamp  # noqa: E501

        :param interview_end_time: The interview_end_time of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: float
        """
        if interview_end_time is None:
            raise ValueError("Invalid value for `interview_end_time`, must not be `None`")  # noqa: E501

        self._interview_end_time = interview_end_time

    @property
    def auto_reminder_trigger_time(self):
        """Gets the auto_reminder_trigger_time of this InviteCandidateResponseDataInvites.  # noqa: E501

        Timestamp of when auto reminder should trigger.  # noqa: E501

        :return: The auto_reminder_trigger_time of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: float
        """
        return self._auto_reminder_trigger_time

    @auto_reminder_trigger_time.setter
    def auto_reminder_trigger_time(self, auto_reminder_trigger_time):
        """Sets the auto_reminder_trigger_time of this InviteCandidateResponseDataInvites.

        Timestamp of when auto reminder should trigger.  # noqa: E501

        :param auto_reminder_trigger_time: The auto_reminder_trigger_time of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: float
        """
        if auto_reminder_trigger_time is None:
            raise ValueError("Invalid value for `auto_reminder_trigger_time`, must not be `None`")  # noqa: E501

        self._auto_reminder_trigger_time = auto_reminder_trigger_time

    @property
    def auto_reminder_info(self):
        """Gets the auto_reminder_info of this InviteCandidateResponseDataInvites.  # noqa: E501


        :return: The auto_reminder_info of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: InviteCandidateResponseDataAutoReminderInfo
        """
        return self._auto_reminder_info

    @auto_reminder_info.setter
    def auto_reminder_info(self, auto_reminder_info):
        """Sets the auto_reminder_info of this InviteCandidateResponseDataInvites.


        :param auto_reminder_info: The auto_reminder_info of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: InviteCandidateResponseDataAutoReminderInfo
        """
        if auto_reminder_info is None:
            raise ValueError("Invalid value for `auto_reminder_info`, must not be `None`")  # noqa: E501

        self._auto_reminder_info = auto_reminder_info

    @property
    def status_code(self):
        """Gets the status_code of this InviteCandidateResponseDataInvites.  # noqa: E501

        0 for success, or specific error code for respective failure case.  # noqa: E501

        :return: The status_code of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: float
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this InviteCandidateResponseDataInvites.

        0 for success, or specific error code for respective failure case.  # noqa: E501

        :param status_code: The status_code of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: float
        """
        if status_code is None:
            raise ValueError("Invalid value for `status_code`, must not be `None`")  # noqa: E501

        self._status_code = status_code

    @property
    def assessment_status(self):
        """Gets the assessment_status of this InviteCandidateResponseDataInvites.  # noqa: E501

        This is the invite status.  # noqa: E501

        :return: The assessment_status of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: str
        """
        return self._assessment_status

    @assessment_status.setter
    def assessment_status(self, assessment_status):
        """Sets the assessment_status of this InviteCandidateResponseDataInvites.

        This is the invite status.  # noqa: E501

        :param assessment_status: The assessment_status of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: str
        """
        if assessment_status is None:
            raise ValueError("Invalid value for `assessment_status`, must not be `None`")  # noqa: E501

        self._assessment_status = assessment_status

    @property
    def status(self):
        """Gets the status of this InviteCandidateResponseDataInvites.  # noqa: E501

        Status whether invite is Success or Failure. for a candidate.  # noqa: E501

        :return: The status of this InviteCandidateResponseDataInvites.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InviteCandidateResponseDataInvites.

        Status whether invite is Success or Failure. for a candidate.  # noqa: E501

        :param status: The status of this InviteCandidateResponseDataInvites.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InviteCandidateResponseDataInvites, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InviteCandidateResponseDataInvites):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    employees-api-referral

    The employee referral APIs are used to refer, track and recommend jobs to external candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.employeesreferral.employee_referrals_api import EmployeeReferralsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.employeesreferral.models.bad_request import BadRequest
from phenom.api.employeesreferral.models.create_employee_referral import CreateEmployeeReferral
from phenom.api.employeesreferral.models.create_employee_referral_questionnaire import CreateEmployeeReferralQuestionnaire
from phenom.api.employeesreferral.models.empty import Empty
from phenom.api.employeesreferral.models.error_response import ErrorResponse
from phenom.api.employeesreferral.models.get_employee_referral_success_response import GetEmployeeReferralSuccessResponse
from phenom.api.employeesreferral.models.get_employee_referral_success_response_candidates import GetEmployeeReferralSuccessResponseCandidates
from phenom.api.employeesreferral.models.get_referral_questionnaire_response import GetReferralQuestionnaireResponse
from phenom.api.employeesreferral.models.get_referral_recommendations_response import GetReferralRecommendationsResponse
from phenom.api.employeesreferral.models.get_referral_recommendations_with_resume import GetReferralRecommendationsWithResume
from phenom.api.employeesreferral.models.job_recommendations import JobRecommendations
from phenom.api.employeesreferral.models.questionnaire import Questionnaire
from phenom.api.employeesreferral.models.referral_data import ReferralData
from phenom.api.employeesreferral.models.referral_data_questionnaire import ReferralDataQuestionnaire
from phenom.api.employeesreferral.models.referral_success_response import ReferralSuccessResponse



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllQuestionnairesResponseDataQuestions(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'questionnaire_id': 'str',
        'date_created': 'int',
        'delete': 'bool',
        'disable': 'bool',
        'draft': 'bool',
        'last_updated': 'int',
        'lc_questionnaire_name': 'str',
        'locales': 'list[GetAllQuestionnairesResponseDataLocales]',
        'question_ids': 'list[str]',
        'questionnaire_details': 'GetAllQuestionnairesResponseDataQuestionnaireDetails',
        'questionnaire_name': 'str',
        'audio_question_count': 'float',
        'mc_question_count': 'float',
        'score_question_count': 'float',
        'text_question_count': 'float',
        'total_questions_count': 'float',
        'video_question_count': 'float',
        'ai_question_count': 'float',
        'knockout_question_count': 'float',
        'manual_question_count': 'float',
        'single_choice_count': 'float',
        'video_or_audio_question_count': 'float'
    }

    attribute_map = {
        'questionnaire_id': 'questionnaireId',
        'date_created': 'dateCreated',
        'delete': 'delete',
        'disable': 'disable',
        'draft': 'draft',
        'last_updated': 'lastUpdated',
        'lc_questionnaire_name': 'lcQuestionnaireName',
        'locales': 'locales',
        'question_ids': 'questionIds',
        'questionnaire_details': 'questionnaireDetails',
        'questionnaire_name': 'questionnaireName',
        'audio_question_count': 'audioQuestionCount',
        'mc_question_count': 'mcQuestionCount',
        'score_question_count': 'scoreQuestionCount',
        'text_question_count': 'textQuestionCount',
        'total_questions_count': 'totalQuestionsCount',
        'video_question_count': 'videoQuestionCount',
        'ai_question_count': 'aiQuestionCount',
        'knockout_question_count': 'knockoutQuestionCount',
        'manual_question_count': 'manualQuestionCount',
        'single_choice_count': 'singleChoiceCount',
        'video_or_audio_question_count': 'videoOrAudioQuestionCount'
    }

    def __init__(self, questionnaire_id=None, date_created=None, delete=None, disable=None, draft=None, last_updated=None, lc_questionnaire_name=None, locales=None, question_ids=None, questionnaire_details=None, questionnaire_name=None, audio_question_count=None, mc_question_count=None, score_question_count=None, text_question_count=None, total_questions_count=None, video_question_count=None, ai_question_count=None, knockout_question_count=None, manual_question_count=None, single_choice_count=None, video_or_audio_question_count=None):  # noqa: E501
        """GetAllQuestionnairesResponseDataQuestions - a model defined in Swagger"""  # noqa: E501
        self._questionnaire_id = None
        self._date_created = None
        self._delete = None
        self._disable = None
        self._draft = None
        self._last_updated = None
        self._lc_questionnaire_name = None
        self._locales = None
        self._question_ids = None
        self._questionnaire_details = None
        self._questionnaire_name = None
        self._audio_question_count = None
        self._mc_question_count = None
        self._score_question_count = None
        self._text_question_count = None
        self._total_questions_count = None
        self._video_question_count = None
        self._ai_question_count = None
        self._knockout_question_count = None
        self._manual_question_count = None
        self._single_choice_count = None
        self._video_or_audio_question_count = None
        self.discriminator = None
        self.questionnaire_id = questionnaire_id
        self.date_created = date_created
        self.delete = delete
        self.disable = disable
        self.draft = draft
        self.last_updated = last_updated
        self.lc_questionnaire_name = lc_questionnaire_name
        if locales is not None:
            self.locales = locales
        if question_ids is not None:
            self.question_ids = question_ids
        self.questionnaire_details = questionnaire_details
        self.questionnaire_name = questionnaire_name
        if audio_question_count is not None:
            self.audio_question_count = audio_question_count
        if mc_question_count is not None:
            self.mc_question_count = mc_question_count
        if score_question_count is not None:
            self.score_question_count = score_question_count
        if text_question_count is not None:
            self.text_question_count = text_question_count
        if total_questions_count is not None:
            self.total_questions_count = total_questions_count
        if video_question_count is not None:
            self.video_question_count = video_question_count
        if ai_question_count is not None:
            self.ai_question_count = ai_question_count
        if knockout_question_count is not None:
            self.knockout_question_count = knockout_question_count
        if manual_question_count is not None:
            self.manual_question_count = manual_question_count
        if single_choice_count is not None:
            self.single_choice_count = single_choice_count
        if video_or_audio_question_count is not None:
            self.video_or_audio_question_count = video_or_audio_question_count

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Total count of questionnaires.  # noqa: E501

        :return: The questionnaire_id of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this GetAllQuestionnairesResponseDataQuestions.

        Total count of questionnaires.  # noqa: E501

        :param questionnaire_id: The questionnaire_id of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if questionnaire_id is None:
            raise ValueError("Invalid value for `questionnaire_id`, must not be `None`")  # noqa: E501

        self._questionnaire_id = questionnaire_id

    @property
    def date_created(self):
        """Gets the date_created of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Date when questionnaire is created.  # noqa: E501

        :return: The date_created of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this GetAllQuestionnairesResponseDataQuestions.

        Date when questionnaire is created.  # noqa: E501

        :param date_created: The date_created of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def delete(self):
        """Gets the delete of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Indicates whether deleted. true if deleted else false.  # noqa: E501

        :return: The delete of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this GetAllQuestionnairesResponseDataQuestions.

        Indicates whether deleted. true if deleted else false.  # noqa: E501

        :param delete: The delete of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: bool
        """
        if delete is None:
            raise ValueError("Invalid value for `delete`, must not be `None`")  # noqa: E501

        self._delete = delete

    @property
    def disable(self):
        """Gets the disable of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Indicates whether questionnaire is disabled.  # noqa: E501

        :return: The disable of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: bool
        """
        return self._disable

    @disable.setter
    def disable(self, disable):
        """Sets the disable of this GetAllQuestionnairesResponseDataQuestions.

        Indicates whether questionnaire is disabled.  # noqa: E501

        :param disable: The disable of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: bool
        """
        if disable is None:
            raise ValueError("Invalid value for `disable`, must not be `None`")  # noqa: E501

        self._disable = disable

    @property
    def draft(self):
        """Gets the draft of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Indicates whether questionnaire is in draft.  # noqa: E501

        :return: The draft of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: bool
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """Sets the draft of this GetAllQuestionnairesResponseDataQuestions.

        Indicates whether questionnaire is in draft.  # noqa: E501

        :param draft: The draft of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: bool
        """
        if draft is None:
            raise ValueError("Invalid value for `draft`, must not be `None`")  # noqa: E501

        self._draft = draft

    @property
    def last_updated(self):
        """Gets the last_updated of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Date when questionnaire is last updated.  # noqa: E501

        :return: The last_updated of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this GetAllQuestionnairesResponseDataQuestions.

        Date when questionnaire is last updated.  # noqa: E501

        :param last_updated: The last_updated of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    @property
    def lc_questionnaire_name(self):
        """Gets the lc_questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Questionnaire name in lowercase.  # noqa: E501

        :return: The lc_questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._lc_questionnaire_name

    @lc_questionnaire_name.setter
    def lc_questionnaire_name(self, lc_questionnaire_name):
        """Sets the lc_questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.

        Questionnaire name in lowercase.  # noqa: E501

        :param lc_questionnaire_name: The lc_questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if lc_questionnaire_name is None:
            raise ValueError("Invalid value for `lc_questionnaire_name`, must not be `None`")  # noqa: E501

        self._lc_questionnaire_name = lc_questionnaire_name

    @property
    def locales(self):
        """Gets the locales of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Locales applicable for the questions to be translated.  # noqa: E501

        :return: The locales of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: list[GetAllQuestionnairesResponseDataLocales]
        """
        return self._locales

    @locales.setter
    def locales(self, locales):
        """Sets the locales of this GetAllQuestionnairesResponseDataQuestions.

        Locales applicable for the questions to be translated.  # noqa: E501

        :param locales: The locales of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: list[GetAllQuestionnairesResponseDataLocales]
        """

        self._locales = locales

    @property
    def question_ids(self):
        """Gets the question_ids of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501


        :return: The question_ids of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: list[str]
        """
        return self._question_ids

    @question_ids.setter
    def question_ids(self, question_ids):
        """Sets the question_ids of this GetAllQuestionnairesResponseDataQuestions.


        :param question_ids: The question_ids of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: list[str]
        """

        self._question_ids = question_ids

    @property
    def questionnaire_details(self):
        """Gets the questionnaire_details of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501


        :return: The questionnaire_details of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: GetAllQuestionnairesResponseDataQuestionnaireDetails
        """
        return self._questionnaire_details

    @questionnaire_details.setter
    def questionnaire_details(self, questionnaire_details):
        """Sets the questionnaire_details of this GetAllQuestionnairesResponseDataQuestions.


        :param questionnaire_details: The questionnaire_details of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: GetAllQuestionnairesResponseDataQuestionnaireDetails
        """
        if questionnaire_details is None:
            raise ValueError("Invalid value for `questionnaire_details`, must not be `None`")  # noqa: E501

        self._questionnaire_details = questionnaire_details

    @property
    def questionnaire_name(self):
        """Gets the questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Questionnaire name of the question.  # noqa: E501

        :return: The questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_name

    @questionnaire_name.setter
    def questionnaire_name(self, questionnaire_name):
        """Sets the questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.

        Questionnaire name of the question.  # noqa: E501

        :param questionnaire_name: The questionnaire_name of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: str
        """
        if questionnaire_name is None:
            raise ValueError("Invalid value for `questionnaire_name`, must not be `None`")  # noqa: E501

        self._questionnaire_name = questionnaire_name

    @property
    def audio_question_count(self):
        """Gets the audio_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of audio question.  # noqa: E501

        :return: The audio_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._audio_question_count

    @audio_question_count.setter
    def audio_question_count(self, audio_question_count):
        """Sets the audio_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of audio question.  # noqa: E501

        :param audio_question_count: The audio_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._audio_question_count = audio_question_count

    @property
    def mc_question_count(self):
        """Gets the mc_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of multichoice question.  # noqa: E501

        :return: The mc_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._mc_question_count

    @mc_question_count.setter
    def mc_question_count(self, mc_question_count):
        """Sets the mc_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of multichoice question.  # noqa: E501

        :param mc_question_count: The mc_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._mc_question_count = mc_question_count

    @property
    def score_question_count(self):
        """Gets the score_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of score question.  # noqa: E501

        :return: The score_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._score_question_count

    @score_question_count.setter
    def score_question_count(self, score_question_count):
        """Sets the score_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of score question.  # noqa: E501

        :param score_question_count: The score_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._score_question_count = score_question_count

    @property
    def text_question_count(self):
        """Gets the text_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of text question.  # noqa: E501

        :return: The text_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._text_question_count

    @text_question_count.setter
    def text_question_count(self, text_question_count):
        """Sets the text_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of text question.  # noqa: E501

        :param text_question_count: The text_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._text_question_count = text_question_count

    @property
    def total_questions_count(self):
        """Gets the total_questions_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of all questions.  # noqa: E501

        :return: The total_questions_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._total_questions_count

    @total_questions_count.setter
    def total_questions_count(self, total_questions_count):
        """Sets the total_questions_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of all questions.  # noqa: E501

        :param total_questions_count: The total_questions_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._total_questions_count = total_questions_count

    @property
    def video_question_count(self):
        """Gets the video_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of video question.  # noqa: E501

        :return: The video_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._video_question_count

    @video_question_count.setter
    def video_question_count(self, video_question_count):
        """Sets the video_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of video question.  # noqa: E501

        :param video_question_count: The video_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._video_question_count = video_question_count

    @property
    def ai_question_count(self):
        """Gets the ai_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of ai generated question.  # noqa: E501

        :return: The ai_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._ai_question_count

    @ai_question_count.setter
    def ai_question_count(self, ai_question_count):
        """Sets the ai_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of ai generated question.  # noqa: E501

        :param ai_question_count: The ai_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._ai_question_count = ai_question_count

    @property
    def knockout_question_count(self):
        """Gets the knockout_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of knockout question.  # noqa: E501

        :return: The knockout_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._knockout_question_count

    @knockout_question_count.setter
    def knockout_question_count(self, knockout_question_count):
        """Sets the knockout_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of knockout question.  # noqa: E501

        :param knockout_question_count: The knockout_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._knockout_question_count = knockout_question_count

    @property
    def manual_question_count(self):
        """Gets the manual_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of manual question.  # noqa: E501

        :return: The manual_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._manual_question_count

    @manual_question_count.setter
    def manual_question_count(self, manual_question_count):
        """Sets the manual_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of manual question.  # noqa: E501

        :param manual_question_count: The manual_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._manual_question_count = manual_question_count

    @property
    def single_choice_count(self):
        """Gets the single_choice_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of single choice question.  # noqa: E501

        :return: The single_choice_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._single_choice_count

    @single_choice_count.setter
    def single_choice_count(self, single_choice_count):
        """Sets the single_choice_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of single choice question.  # noqa: E501

        :param single_choice_count: The single_choice_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._single_choice_count = single_choice_count

    @property
    def video_or_audio_question_count(self):
        """Gets the video_or_audio_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501

        Count of video or audio question.  # noqa: E501

        :return: The video_or_audio_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :rtype: float
        """
        return self._video_or_audio_question_count

    @video_or_audio_question_count.setter
    def video_or_audio_question_count(self, video_or_audio_question_count):
        """Sets the video_or_audio_question_count of this GetAllQuestionnairesResponseDataQuestions.

        Count of video or audio question.  # noqa: E501

        :param video_or_audio_question_count: The video_or_audio_question_count of this GetAllQuestionnairesResponseDataQuestions.  # noqa: E501
        :type: float
        """

        self._video_or_audio_question_count = video_or_audio_question_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllQuestionnairesResponseDataQuestions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllQuestionnairesResponseDataQuestions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignOptInHistoryDetailsPageableSort(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sorted': 'bool',
        'empty': 'bool',
        'unsorted': 'bool'
    }

    attribute_map = {
        'sorted': 'sorted',
        'empty': 'empty',
        'unsorted': 'unsorted'
    }

    def __init__(self, sorted=None, empty=None, unsorted=None):  # noqa: E501
        """EmailCampaignOptInHistoryDetailsPageableSort - a model defined in Swagger"""  # noqa: E501
        self._sorted = None
        self._empty = None
        self._unsorted = None
        self.discriminator = None
        self.sorted = sorted
        self.empty = empty
        self.unsorted = unsorted

    @property
    def sorted(self):
        """Gets the sorted of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501

        Indicates whether the list is sorted.  # noqa: E501

        :return: The sorted of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501
        :rtype: bool
        """
        return self._sorted

    @sorted.setter
    def sorted(self, sorted):
        """Sets the sorted of this EmailCampaignOptInHistoryDetailsPageableSort.

        Indicates whether the list is sorted.  # noqa: E501

        :param sorted: The sorted of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501
        :type: bool
        """
        if sorted is None:
            raise ValueError("Invalid value for `sorted`, must not be `None`")  # noqa: E501

        self._sorted = sorted

    @property
    def empty(self):
        """Gets the empty of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501

        Indicates whether the sorting is empty.  # noqa: E501

        :return: The empty of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this EmailCampaignOptInHistoryDetailsPageableSort.

        Indicates whether the sorting is empty.  # noqa: E501

        :param empty: The empty of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501
        :type: bool
        """
        if empty is None:
            raise ValueError("Invalid value for `empty`, must not be `None`")  # noqa: E501

        self._empty = empty

    @property
    def unsorted(self):
        """Gets the unsorted of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501

        Indicates whether the list is unsorted.  # noqa: E501

        :return: The unsorted of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501
        :rtype: bool
        """
        return self._unsorted

    @unsorted.setter
    def unsorted(self, unsorted):
        """Sets the unsorted of this EmailCampaignOptInHistoryDetailsPageableSort.

        Indicates whether the list is unsorted.  # noqa: E501

        :param unsorted: The unsorted of this EmailCampaignOptInHistoryDetailsPageableSort.  # noqa: E501
        :type: bool
        """
        if unsorted is None:
            raise ValueError("Invalid value for `unsorted`, must not be `None`")  # noqa: E501

        self._unsorted = unsorted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignOptInHistoryDetailsPageableSort, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignOptInHistoryDetailsPageableSort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AdditionalFields(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'AdditionalFieldsData',
        'message': 'str',
        'status': 'str'
    }

    attribute_map = {
        'data': 'data',
        'message': 'message',
        'status': 'status'
    }

    def __init__(self, data=None, message=None, status=None):  # noqa: E501
        """AdditionalFields - a model defined in Swagger"""  # noqa: E501
        self._data = None
        self._message = None
        self._status = None
        self.discriminator = None
        if data is not None:
            self.data = data
        if message is not None:
            self.message = message
        if status is not None:
            self.status = status

    @property
    def data(self):
        """Gets the data of this AdditionalFields.  # noqa: E501


        :return: The data of this AdditionalFields.  # noqa: E501
        :rtype: AdditionalFieldsData
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this AdditionalFields.


        :param data: The data of this AdditionalFields.  # noqa: E501
        :type: AdditionalFieldsData
        """

        self._data = data

    @property
    def message(self):
        """Gets the message of this AdditionalFields.  # noqa: E501

        A message related to the additional fields.  # noqa: E501

        :return: The message of this AdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AdditionalFields.

        A message related to the additional fields.  # noqa: E501

        :param message: The message of this AdditionalFields.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def status(self):
        """Gets the status of this AdditionalFields.  # noqa: E501

        The overall status of the additional fields response.  # noqa: E501

        :return: The status of this AdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AdditionalFields.

        The overall status of the additional fields response.  # noqa: E501

        :param status: The status of this AdditionalFields.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdditionalFields, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdditionalFields):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UserProfile(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'categories': 'list[str]',
        'skills': 'list[str]',
        'title': 'str',
        'years_of_experience': 'str',
        'preferred_locations': 'list[PreferredLocations]'
    }

    attribute_map = {
        'categories': 'categories',
        'skills': 'skills',
        'title': 'title',
        'years_of_experience': 'yearsOfExperience',
        'preferred_locations': 'preferredLocations'
    }

    def __init__(self, categories=None, skills=None, title=None, years_of_experience=None, preferred_locations=None):  # noqa: E501
        """UserProfile - a model defined in Swagger"""  # noqa: E501
        self._categories = None
        self._skills = None
        self._title = None
        self._years_of_experience = None
        self._preferred_locations = None
        self.discriminator = None
        if categories is not None:
            self.categories = categories
        if skills is not None:
            self.skills = skills
        if title is not None:
            self.title = title
        if years_of_experience is not None:
            self.years_of_experience = years_of_experience
        if preferred_locations is not None:
            self.preferred_locations = preferred_locations

    @property
    def categories(self):
        """Gets the categories of this UserProfile.  # noqa: E501


        :return: The categories of this UserProfile.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this UserProfile.


        :param categories: The categories of this UserProfile.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    @property
    def skills(self):
        """Gets the skills of this UserProfile.  # noqa: E501


        :return: The skills of this UserProfile.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """Sets the skills of this UserProfile.


        :param skills: The skills of this UserProfile.  # noqa: E501
        :type: list[str]
        """

        self._skills = skills

    @property
    def title(self):
        """Gets the title of this UserProfile.  # noqa: E501

        Recent designation of the user.  # noqa: E501

        :return: The title of this UserProfile.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this UserProfile.

        Recent designation of the user.  # noqa: E501

        :param title: The title of this UserProfile.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def years_of_experience(self):
        """Gets the years_of_experience of this UserProfile.  # noqa: E501

        Total number of years of experience of the user.  # noqa: E501

        :return: The years_of_experience of this UserProfile.  # noqa: E501
        :rtype: str
        """
        return self._years_of_experience

    @years_of_experience.setter
    def years_of_experience(self, years_of_experience):
        """Sets the years_of_experience of this UserProfile.

        Total number of years of experience of the user.  # noqa: E501

        :param years_of_experience: The years_of_experience of this UserProfile.  # noqa: E501
        :type: str
        """

        self._years_of_experience = years_of_experience

    @property
    def preferred_locations(self):
        """Gets the preferred_locations of this UserProfile.  # noqa: E501


        :return: The preferred_locations of this UserProfile.  # noqa: E501
        :rtype: list[PreferredLocations]
        """
        return self._preferred_locations

    @preferred_locations.setter
    def preferred_locations(self, preferred_locations):
        """Sets the preferred_locations of this UserProfile.


        :param preferred_locations: The preferred_locations of this UserProfile.  # noqa: E501
        :type: list[PreferredLocations]
        """

        self._preferred_locations = preferred_locations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AlreadyAppliedData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'already_applied': 'bool',
        'candidate_id': 'str',
        'application_id': 'str'
    }

    attribute_map = {
        'already_applied': 'alreadyApplied',
        'candidate_id': 'candidateId',
        'application_id': 'applicationId'
    }

    def __init__(self, already_applied=None, candidate_id=None, application_id=None):  # noqa: E501
        """AlreadyAppliedData - a model defined in Swagger"""  # noqa: E501
        self._already_applied = None
        self._candidate_id = None
        self._application_id = None
        self.discriminator = None
        if already_applied is not None:
            self.already_applied = already_applied
        if candidate_id is not None:
            self.candidate_id = candidate_id
        if application_id is not None:
            self.application_id = application_id

    @property
    def already_applied(self):
        """Gets the already_applied of this AlreadyAppliedData.  # noqa: E501

        It equals true if the application is already applied by the candidate.  # noqa: E501

        :return: The already_applied of this AlreadyAppliedData.  # noqa: E501
        :rtype: bool
        """
        return self._already_applied

    @already_applied.setter
    def already_applied(self, already_applied):
        """Sets the already_applied of this AlreadyAppliedData.

        It equals true if the application is already applied by the candidate.  # noqa: E501

        :param already_applied: The already_applied of this AlreadyAppliedData.  # noqa: E501
        :type: bool
        """

        self._already_applied = already_applied

    @property
    def candidate_id(self):
        """Gets the candidate_id of this AlreadyAppliedData.  # noqa: E501

        It is a 24-digit hexadecimal value that represents Applicant Id.  # noqa: E501

        :return: The candidate_id of this AlreadyAppliedData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this AlreadyAppliedData.

        It is a 24-digit hexadecimal value that represents Applicant Id.  # noqa: E501

        :param candidate_id: The candidate_id of this AlreadyAppliedData.  # noqa: E501
        :type: str
        """

        self._candidate_id = candidate_id

    @property
    def application_id(self):
        """Gets the application_id of this AlreadyAppliedData.  # noqa: E501

        It is a 24-digit hexadecimal value that represents Application Id.  # noqa: E501

        :return: The application_id of this AlreadyAppliedData.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this AlreadyAppliedData.

        It is a 24-digit hexadecimal value that represents Application Id.  # noqa: E501

        :param application_id: The application_id of this AlreadyAppliedData.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlreadyAppliedData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlreadyAppliedData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    servicehub-scim-api

    API endpoints for user management, utilizing the SCIM protocol.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ScimUser(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'schemas': 'list[str]',
        'id': 'str',
        'user_name': 'str',
        'name': 'ScimUserName',
        'display_name': 'str',
        'title': 'str',
        'user_type': 'str',
        'active': 'bool',
        'emails': 'list[ScimUserEmails]',
        'photos': 'list[ScimUserPhotos]',
        'phone_numbers': 'list[ScimUserPhoneNumbers]',
        'addresses': 'list[ScimUserAddresses]',
        'roles': 'list[ScimUserRoles]',
        'groups': 'list[ScimUserGroups]',
        'entitlements': 'list[ScimUserEntitlements]'
    }

    attribute_map = {
        'schemas': 'schemas',
        'id': 'id',
        'user_name': 'userName',
        'name': 'name',
        'display_name': 'displayName',
        'title': 'title',
        'user_type': 'userType',
        'active': 'active',
        'emails': 'emails',
        'photos': 'photos',
        'phone_numbers': 'phoneNumbers',
        'addresses': 'addresses',
        'roles': 'roles',
        'groups': 'groups',
        'entitlements': 'entitlements'
    }

    def __init__(self, schemas=None, id=None, user_name=None, name=None, display_name=None, title=None, user_type=None, active=None, emails=None, photos=None, phone_numbers=None, addresses=None, roles=None, groups=None, entitlements=None):  # noqa: E501
        """ScimUser - a model defined in Swagger"""  # noqa: E501
        self._schemas = None
        self._id = None
        self._user_name = None
        self._name = None
        self._display_name = None
        self._title = None
        self._user_type = None
        self._active = None
        self._emails = None
        self._photos = None
        self._phone_numbers = None
        self._addresses = None
        self._roles = None
        self._groups = None
        self._entitlements = None
        self.discriminator = None
        if schemas is not None:
            self.schemas = schemas
        if id is not None:
            self.id = id
        if user_name is not None:
            self.user_name = user_name
        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if title is not None:
            self.title = title
        if user_type is not None:
            self.user_type = user_type
        if active is not None:
            self.active = active
        if emails is not None:
            self.emails = emails
        if photos is not None:
            self.photos = photos
        if phone_numbers is not None:
            self.phone_numbers = phone_numbers
        if addresses is not None:
            self.addresses = addresses
        if roles is not None:
            self.roles = roles
        if groups is not None:
            self.groups = groups
        if entitlements is not None:
            self.entitlements = entitlements

    @property
    def schemas(self):
        """Gets the schemas of this ScimUser.  # noqa: E501

        An array of strings indicating the available schemas for the resource.  # noqa: E501

        :return: The schemas of this ScimUser.  # noqa: E501
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """Sets the schemas of this ScimUser.

        An array of strings indicating the available schemas for the resource.  # noqa: E501

        :param schemas: The schemas of this ScimUser.  # noqa: E501
        :type: list[str]
        """

        self._schemas = schemas

    @property
    def id(self):
        """Gets the id of this ScimUser.  # noqa: E501

        The unique identifier for the User.  # noqa: E501

        :return: The id of this ScimUser.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScimUser.

        The unique identifier for the User.  # noqa: E501

        :param id: The id of this ScimUser.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_name(self):
        """Gets the user_name of this ScimUser.  # noqa: E501

        Unique identifier for the User, typically used by the user to directly authenticate to the service provider.  # noqa: E501

        :return: The user_name of this ScimUser.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ScimUser.

        Unique identifier for the User, typically used by the user to directly authenticate to the service provider.  # noqa: E501

        :param user_name: The user_name of this ScimUser.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def name(self):
        """Gets the name of this ScimUser.  # noqa: E501


        :return: The name of this ScimUser.  # noqa: E501
        :rtype: ScimUserName
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ScimUser.


        :param name: The name of this ScimUser.  # noqa: E501
        :type: ScimUserName
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this ScimUser.  # noqa: E501

        User's display name.  # noqa: E501

        :return: The display_name of this ScimUser.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this ScimUser.

        User's display name.  # noqa: E501

        :param display_name: The display_name of this ScimUser.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def title(self):
        """Gets the title of this ScimUser.  # noqa: E501

        User's title or job position.  # noqa: E501

        :return: The title of this ScimUser.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ScimUser.

        User's title or job position.  # noqa: E501

        :param title: The title of this ScimUser.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def user_type(self):
        """Gets the user_type of this ScimUser.  # noqa: E501

        Type of user.  # noqa: E501

        :return: The user_type of this ScimUser.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this ScimUser.

        Type of user.  # noqa: E501

        :param user_type: The user_type of this ScimUser.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    @property
    def active(self):
        """Gets the active of this ScimUser.  # noqa: E501

        Indicates whether the user is active.  # noqa: E501

        :return: The active of this ScimUser.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this ScimUser.

        Indicates whether the user is active.  # noqa: E501

        :param active: The active of this ScimUser.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def emails(self):
        """Gets the emails of this ScimUser.  # noqa: E501

        User's email addresses.  # noqa: E501

        :return: The emails of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserEmails]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this ScimUser.

        User's email addresses.  # noqa: E501

        :param emails: The emails of this ScimUser.  # noqa: E501
        :type: list[ScimUserEmails]
        """

        self._emails = emails

    @property
    def photos(self):
        """Gets the photos of this ScimUser.  # noqa: E501

        User's photos.  # noqa: E501

        :return: The photos of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserPhotos]
        """
        return self._photos

    @photos.setter
    def photos(self, photos):
        """Sets the photos of this ScimUser.

        User's photos.  # noqa: E501

        :param photos: The photos of this ScimUser.  # noqa: E501
        :type: list[ScimUserPhotos]
        """

        self._photos = photos

    @property
    def phone_numbers(self):
        """Gets the phone_numbers of this ScimUser.  # noqa: E501

        User's phone numbers.  # noqa: E501

        :return: The phone_numbers of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserPhoneNumbers]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """Sets the phone_numbers of this ScimUser.

        User's phone numbers.  # noqa: E501

        :param phone_numbers: The phone_numbers of this ScimUser.  # noqa: E501
        :type: list[ScimUserPhoneNumbers]
        """

        self._phone_numbers = phone_numbers

    @property
    def addresses(self):
        """Gets the addresses of this ScimUser.  # noqa: E501

        User's addresses.  # noqa: E501

        :return: The addresses of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserAddresses]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this ScimUser.

        User's addresses.  # noqa: E501

        :param addresses: The addresses of this ScimUser.  # noqa: E501
        :type: list[ScimUserAddresses]
        """

        self._addresses = addresses

    @property
    def roles(self):
        """Gets the roles of this ScimUser.  # noqa: E501

        An array representing the roles assigned to the user.  # noqa: E501

        :return: The roles of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserRoles]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this ScimUser.

        An array representing the roles assigned to the user.  # noqa: E501

        :param roles: The roles of this ScimUser.  # noqa: E501
        :type: list[ScimUserRoles]
        """

        self._roles = roles

    @property
    def groups(self):
        """Gets the groups of this ScimUser.  # noqa: E501

        An array representing the tenants associated with the user.  # noqa: E501

        :return: The groups of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserGroups]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this ScimUser.

        An array representing the tenants associated with the user.  # noqa: E501

        :param groups: The groups of this ScimUser.  # noqa: E501
        :type: list[ScimUserGroups]
        """

        self._groups = groups

    @property
    def entitlements(self):
        """Gets the entitlements of this ScimUser.  # noqa: E501

        User's entitlements.  # noqa: E501

        :return: The entitlements of this ScimUser.  # noqa: E501
        :rtype: list[ScimUserEntitlements]
        """
        return self._entitlements

    @entitlements.setter
    def entitlements(self, entitlements):
        """Sets the entitlements of this ScimUser.

        User's entitlements.  # noqa: E501

        :param entitlements: The entitlements of this ScimUser.  # noqa: E501
        :type: list[ScimUserEntitlements]
        """

        self._entitlements = entitlements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScimUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScimUser):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    communications-email

    These APIs ensures an easy integration process of email management for developers to send, read, and track email histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailHistoryData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date': 'int',
        'to_name': 'str',
        'subject': 'str',
        'from_name': 'str',
        'to_email': 'str',
        'from_email': 'str',
        'source': 'str',
        'email_activity_id': 'str'
    }

    attribute_map = {
        'created_date': 'createdDate',
        'to_name': 'toName',
        'subject': 'subject',
        'from_name': 'fromName',
        'to_email': 'toEmail',
        'from_email': 'fromEmail',
        'source': 'source',
        'email_activity_id': 'emailActivityId'
    }

    def __init__(self, created_date=None, to_name=None, subject=None, from_name=None, to_email=None, from_email=None, source=None, email_activity_id=None):  # noqa: E501
        """EmailHistoryData - a model defined in Swagger"""  # noqa: E501
        self._created_date = None
        self._to_name = None
        self._subject = None
        self._from_name = None
        self._to_email = None
        self._from_email = None
        self._source = None
        self._email_activity_id = None
        self.discriminator = None
        if created_date is not None:
            self.created_date = created_date
        if to_name is not None:
            self.to_name = to_name
        if subject is not None:
            self.subject = subject
        if from_name is not None:
            self.from_name = from_name
        if to_email is not None:
            self.to_email = to_email
        if from_email is not None:
            self.from_email = from_email
        if source is not None:
            self.source = source
        if email_activity_id is not None:
            self.email_activity_id = email_activity_id

    @property
    def created_date(self):
        """Gets the created_date of this EmailHistoryData.  # noqa: E501

        Email created Date.  # noqa: E501

        :return: The created_date of this EmailHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EmailHistoryData.

        Email created Date.  # noqa: E501

        :param created_date: The created_date of this EmailHistoryData.  # noqa: E501
        :type: int
        """

        self._created_date = created_date

    @property
    def to_name(self):
        """Gets the to_name of this EmailHistoryData.  # noqa: E501

        Recipient's name in the email.  # noqa: E501

        :return: The to_name of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._to_name

    @to_name.setter
    def to_name(self, to_name):
        """Sets the to_name of this EmailHistoryData.

        Recipient's name in the email.  # noqa: E501

        :param to_name: The to_name of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._to_name = to_name

    @property
    def subject(self):
        """Gets the subject of this EmailHistoryData.  # noqa: E501

        Subject of the email.  # noqa: E501

        :return: The subject of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailHistoryData.

        Subject of the email.  # noqa: E501

        :param subject: The subject of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def from_name(self):
        """Gets the from_name of this EmailHistoryData.  # noqa: E501

        Sender Name in the email.  # noqa: E501

        :return: The from_name of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """Sets the from_name of this EmailHistoryData.

        Sender Name in the email.  # noqa: E501

        :param from_name: The from_name of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._from_name = from_name

    @property
    def to_email(self):
        """Gets the to_email of this EmailHistoryData.  # noqa: E501

        Recipient's email address.  # noqa: E501

        :return: The to_email of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._to_email

    @to_email.setter
    def to_email(self, to_email):
        """Sets the to_email of this EmailHistoryData.

        Recipient's email address.  # noqa: E501

        :param to_email: The to_email of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._to_email = to_email

    @property
    def from_email(self):
        """Gets the from_email of this EmailHistoryData.  # noqa: E501

        Sender's email address.  # noqa: E501

        :return: The from_email of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._from_email

    @from_email.setter
    def from_email(self, from_email):
        """Sets the from_email of this EmailHistoryData.

        Sender's email address.  # noqa: E501

        :param from_email: The from_email of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._from_email = from_email

    @property
    def source(self):
        """Gets the source of this EmailHistoryData.  # noqa: E501

        Source for the email history.  # noqa: E501

        :return: The source of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this EmailHistoryData.

        Source for the email history.  # noqa: E501

        :param source: The source of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def email_activity_id(self):
        """Gets the email_activity_id of this EmailHistoryData.  # noqa: E501

        Activity ID of the email.  # noqa: E501

        :return: The email_activity_id of this EmailHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._email_activity_id

    @email_activity_id.setter
    def email_activity_id(self, email_activity_id):
        """Sets the email_activity_id of this EmailHistoryData.

        Activity ID of the email.  # noqa: E501

        :param email_activity_id: The email_activity_id of this EmailHistoryData.  # noqa: E501
        :type: str
        """

        self._email_activity_id = email_activity_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailHistoryData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailHistoryData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
